@@ -458,6 +458,7 @@ class FanPacket(ImazuPacket):
 
     - ON / 3
     > f7 0b 01 2b 02 42 11 07 00 80 ee
+    < f7 0c 01 2b 04 42 11 07 0107 87 ee
     < f7 0c 01 2b 04 41 2b0440 11 00 0107 82 ee
     """
 
@@ -485,7 +486,7 @@ class FanPacket(ImazuPacket):
                 'speed': FanPacket.Speed(state_value[1]),
             }
 
-        if self.value_type == ValueType.BOOL:
+        if self.value_type in [ValueType.BOOL, ValueType.DIM]:
             self.state = parse_state(self.state_value)
             return [self]
 
